@@ -3,7 +3,7 @@
                              -------------------
     begin                : Feb 12, 2005
     copyright            : (C) 2005 by Lalescu Liviu
-    email                : liviu@lalescu.ro
+    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -34,9 +34,10 @@
 class ModifyRoomForm : public ModifyRoomForm_template {
 	QString _initialRoomName;
 	QString _initialRoomType;
+	QString _initialRoomBuilding;
 	int _initialRoomCapacity;
 public: 
-	ModifyRoomForm(const QString& initialRoomName, const QString& initialRoomType, int initialRoomCapacity);
+	ModifyRoomForm(const QString& initialRoomName, const QString& initialRoomType, const QString& initialRoomBuilding, int initialRoomCapacity);
 	~ModifyRoomForm();
 
 	void ok();
