@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Apr 22 2003
     copyright            : (C) 2003 by Lalescu Liviu
-    email                : liviu@lalescu.ro
+    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
  ***************************************************************************/
 
 /***************************************************************************
@@ -36,14 +36,15 @@
 #include <qtextedit.h>
 #include <qstring.h>
 
+extern bool students_schedule_ready;
+extern bool teachers_schedule_ready;
 
-extern bool students_schedule_ready, teachers_schedule_ready;
+extern bool simulation_running;
 
+extern TimeChromosome best_time_chromosome;
 
 TimetableViewStudentsForm::TimetableViewStudentsForm()
 {
-	assert(gt.rules.internalStructureComputed);
-
 	yearsListBox->clear();
 	for(StudentsYear* sty=gt.rules.yearsList.first(); sty; sty=gt.rules.yearsList.next())
 		yearsListBox->insertItem(sty->name);
@@ -145,14 +146,16 @@ void TimetableViewStudentsForm::updateStudentsTimetableTable(){
 		for(int k=0; k<gt.rules.nDaysPerWeek; k++){
 			s="";
 			int ai=students_timetable_week1[i][k][j]; //activity index
-			Activity* act=gt.rules.activitiesList.at(ai);
+			//Activity* act=gt.rules.activitiesList.at(ai);
 			if(ai!=UNALLOCATED_ACTIVITY){
+				Activity* act=&gt.rules.internalActivitiesList[ai];
 				assert(act!=NULL);
 				s+=act->subjectName + " " + act->subjectTagName;
 			}
 			ai=students_timetable_week2[i][k][j]; //activity index
-			act=gt.rules.activitiesList.at(ai);
+			//act=gt.rules.activitiesList.at(ai);
 			if(ai!=UNALLOCATED_ACTIVITY){
+				Activity* act=&gt.rules.internalActivitiesList[ai];
 				assert(act!=NULL);
 				s += " / " + act->subjectName + " " + act->subjectTagName;
 			}
@@ -195,18 +198,102 @@ void TimetableViewStudentsForm::detailActivity(int row, int col)
 	s="";
 	if(j>=0 && k>=0){
 		int ai=students_timetable_week1[i][k][j]; //activity index
-		Activity* act=gt.rules.activitiesList.at(ai);
+		//Activity* act=gt.rules.activitiesList.at(ai);
 		if(ai!=UNALLOCATED_ACTIVITY){
+			Activity* act=&gt.rules.internalActivitiesList[ai];
 			assert(act!=NULL);
-			s+=act->getDetailedDescription(gt.rules);
+			s+=act->getDetailedDescriptionWithConstraints(gt.rules);
 		}
 		ai=students_timetable_week2[i][k][j]; //activity index
-		act=gt.rules.activitiesList.at(ai);
+		//act=gt.rules.activitiesList.at(ai);
 		if(ai!=UNALLOCATED_ACTIVITY){
+			Activity* act=&gt.rules.internalActivitiesList[ai];
 			assert(act!=NULL);
 			s+="/\n";
-			s+=act->getDetailedDescription(gt.rules);
+			s+=act->getDetailedDescriptionWithConstraints(gt.rules);
 		}
 	}
 	detailsTextEdit->setText(s);
 }
+
+void TimetableViewStudentsForm::lock()
+{
+	if(simulation_running){
+		QMessageBox::information(this, QObject::tr("FET information"),
+			QObject::tr("Allocation in course.\nPlease stop simulation before this."));
+		return;
+	}
+
+	//find subgroup index
+	assert(students_schedule_ready && teachers_schedule_ready);
+
+	QString yearname;
+	QString groupname;
+	QString subgroupname;
+
+	if(yearsListBox->currentText()==NULL)
+		return;
+	if(groupsListBox->currentText()==NULL)
+		return;
+	if(subgroupsListBox->currentText()==NULL)
+		return;
+
+	yearname = yearsListBox->currentText();
+	groupname = groupsListBox->currentText();
+	subgroupname = subgroupsListBox->currentText();
+
+	TimeChromosome* tc=&best_time_chromosome;
+
+	StudentsSubgroup* sts=(StudentsSubgroup*)gt.rules.searchStudentsSet(subgroupname);
+	assert(sts);
+	int i;
+	for(i=0; i<gt.rules.nInternalSubgroups; i++)
+		if(gt.rules.internalSubgroupsList[i]==sts)
+			break;
+	assert(i<gt.rules.nInternalSubgroups);
+
+	//lock selected activities
+	for(int j=0; j<gt.rules.nHoursPerDay; j++){
+		for(int k=0; k<gt.rules.nDaysPerWeek; k++){
+			if(studentsTimetableTable->isSelected(j+1, k+1)){
+				int ai=students_timetable_week1[i][k][j];
+				if(ai!=UNALLOCATED_ACTIVITY){
+					int time=tc->times[ai];
+					int hour=time/gt.rules.nDaysPerWeek;
+					int day=time%gt.rules.nDaysPerWeek;
+					//Activity* act=gt.rules.activitiesList.at(ai);
+					Activity* act=&gt.rules.internalActivitiesList[ai];
+					ConstraintActivityPreferredTime* ctr=new ConstraintActivityPreferredTime(1, true, act->id, day, hour);
+					bool t=gt.rules.addTimeConstraint(ctr);
+					if(t)
+						QMessageBox::information(this, QObject::tr("FET information"), 
+						 QObject::tr("Added the following constraint:\n"+ctr->getDetailedDescription(gt.rules)));
+					else{
+						QMessageBox::warning(this, QObject::tr("FET information"), 
+						 QObject::tr("Constraint\n%1 NOT added - duplicate").arg(ctr->getDetailedDescription(gt.rules)));
+						delete ctr;
+					}
+				}
+				
+				ai=students_timetable_week2[i][k][j];
+				if(ai!=UNALLOCATED_ACTIVITY){
+					int time=tc->times[ai];
+					int hour=time/gt.rules.nDaysPerWeek;
+					int day=time%gt.rules.nDaysPerWeek;
+					//Activity* act=gt.rules.activitiesList.at(ai);
+					Activity* act=&gt.rules.internalActivitiesList[ai];
+					ConstraintActivityPreferredTime* ctr=new ConstraintActivityPreferredTime(1, true, act->id, day, hour);
+					bool t=gt.rules.addTimeConstraint(ctr);
+					if(t)
+						QMessageBox::information(this, QObject::tr("FET information"), 
+						 QObject::tr("Added the following constraint:\n"+ctr->getDetailedDescription(gt.rules)));
+					else{
+						QMessageBox::warning(this, QObject::tr("FET information"), 
+						 QObject::tr("Constraint\n%1 NOT added - duplicate").arg(ctr->getDetailedDescription(gt.rules)));
+						delete ctr;
+					}
+				}
+			}
+		}
+	}
+}
